@@ -64,7 +64,7 @@ class Exceptions:
 
 class ComputeOptimizerClient:
     """
-    [ComputeOptimizer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.13/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
+    [ComputeOptimizer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.15/reference/services/compute-optimizer.html#ComputeOptimizer.Client)
     """
 
     meta: ClientMeta
@@ -72,7 +72,7 @@ class ComputeOptimizerClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.13/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.15/reference/services/compute-optimizer.html#ComputeOptimizer.Client.can_paginate)
         """
 
     def describe_recommendation_export_jobs(
@@ -83,7 +83,7 @@ class ComputeOptimizerClient:
         maxResults: int = None,
     ) -> DescribeRecommendationExportJobsResponseTypeDef:
         """
-        [Client.describe_recommendation_export_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.13/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
+        [Client.describe_recommendation_export_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.15/reference/services/compute-optimizer.html#ComputeOptimizer.Client.describe_recommendation_export_jobs)
         """
 
     def export_auto_scaling_group_recommendations(
@@ -99,6 +99,10 @@ class ComputeOptimizerClient:
                 "Finding",
                 "UtilizationMetricsCpuMaximum",
                 "UtilizationMetricsMemoryMaximum",
+                "UtilizationMetricsEbsReadOpsPerSecondMaximum",
+                "UtilizationMetricsEbsWriteOpsPerSecondMaximum",
+                "UtilizationMetricsEbsReadBytesPerSecondMaximum",
+                "UtilizationMetricsEbsWriteBytesPerSecondMaximum",
                 "LookbackPeriodInDays",
                 "CurrentConfigurationInstanceType",
                 "CurrentConfigurationDesiredCapacity",
@@ -132,7 +136,7 @@ class ComputeOptimizerClient:
         includeMemberAccounts: bool = None,
     ) -> ExportAutoScalingGroupRecommendationsResponseTypeDef:
         """
-        [Client.export_auto_scaling_group_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.13/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
+        [Client.export_auto_scaling_group_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.15/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_auto_scaling_group_recommendations)
         """
 
     def export_ec2_instance_recommendations(
@@ -150,6 +154,10 @@ class ComputeOptimizerClient:
                 "CurrentInstanceType",
                 "UtilizationMetricsCpuMaximum",
                 "UtilizationMetricsMemoryMaximum",
+                "UtilizationMetricsEbsReadOpsPerSecondMaximum",
+                "UtilizationMetricsEbsWriteOpsPerSecondMaximum",
+                "UtilizationMetricsEbsReadBytesPerSecondMaximum",
+                "UtilizationMetricsEbsWriteBytesPerSecondMaximum",
                 "CurrentOnDemandPrice",
                 "CurrentStandardOneYearNoUpfrontReservedPrice",
                 "CurrentStandardThreeYearNoUpfrontReservedPrice",
@@ -177,7 +185,7 @@ class ComputeOptimizerClient:
         includeMemberAccounts: bool = None,
     ) -> ExportEC2InstanceRecommendationsResponseTypeDef:
         """
-        [Client.export_ec2_instance_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.13/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
+        [Client.export_ec2_instance_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.15/reference/services/compute-optimizer.html#ComputeOptimizer.Client.export_ec2_instance_recommendations)
         """
 
     def generate_presigned_url(
@@ -188,7 +196,7 @@ class ComputeOptimizerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.13/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.15/reference/services/compute-optimizer.html#ComputeOptimizer.Client.generate_presigned_url)
         """
 
     def get_auto_scaling_group_recommendations(
@@ -200,7 +208,7 @@ class ComputeOptimizerClient:
         filters: List[FilterTypeDef] = None,
     ) -> GetAutoScalingGroupRecommendationsResponseTypeDef:
         """
-        [Client.get_auto_scaling_group_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.13/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
+        [Client.get_auto_scaling_group_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.15/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_auto_scaling_group_recommendations)
         """
 
     def get_ec2_instance_recommendations(
@@ -212,7 +220,7 @@ class ComputeOptimizerClient:
         accountIds: List[str] = None,
     ) -> GetEC2InstanceRecommendationsResponseTypeDef:
         """
-        [Client.get_ec2_instance_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.13/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
+        [Client.get_ec2_instance_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.15/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_instance_recommendations)
         """
 
     def get_ec2_recommendation_projected_metrics(
@@ -224,19 +232,19 @@ class ComputeOptimizerClient:
         endTime: datetime,
     ) -> GetEC2RecommendationProjectedMetricsResponseTypeDef:
         """
-        [Client.get_ec2_recommendation_projected_metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.13/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
+        [Client.get_ec2_recommendation_projected_metrics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.15/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_ec2_recommendation_projected_metrics)
         """
 
     def get_enrollment_status(self) -> GetEnrollmentStatusResponseTypeDef:
         """
-        [Client.get_enrollment_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.13/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
+        [Client.get_enrollment_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.15/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_enrollment_status)
         """
 
     def get_recommendation_summaries(
         self, accountIds: List[str] = None, nextToken: str = None, maxResults: int = None
     ) -> GetRecommendationSummariesResponseTypeDef:
         """
-        [Client.get_recommendation_summaries documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.13/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
+        [Client.get_recommendation_summaries documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.15/reference/services/compute-optimizer.html#ComputeOptimizer.Client.get_recommendation_summaries)
         """
 
     def update_enrollment_status(
@@ -245,5 +253,5 @@ class ComputeOptimizerClient:
         includeMemberAccounts: bool = None,
     ) -> UpdateEnrollmentStatusResponseTypeDef:
         """
-        [Client.update_enrollment_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.13/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
+        [Client.update_enrollment_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.15.15/reference/services/compute-optimizer.html#ComputeOptimizer.Client.update_enrollment_status)
         """
